==> apo-ws-client-6.00.50.2-sources.jar: fr/univlorraine/apowsclient/creationSE/ListeElementPedagogiDTO3.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ListeElementPedagogiDTO3 complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ListeElementPedagogiDTO3"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codListeElp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="typListeElp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="libCourtListeElp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="libListeElp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="temSpecialTraitementPRC" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="listElementPedagogi" type="{ListeElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}TableauElementPedagogiDTO3"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ListeElementPedagogiDTO3", namespace = "ListeElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codListeElp",
    "typListeElp",
    "libCourtListeElp",
    "libListeElp",
    "temSpecialTraitementPRC",
    "listElementPedagogi"
})
public class ListeElementPedagogiDTO3 {

    @XmlElement(required = true, nillable = true)
    protected String codListeElp;
    @XmlElement(required = true, nillable = true)
    protected String typListeElp;
    @XmlElement(required = true, nillable = true)
    protected String libCourtListeElp;
    @XmlElement(required = true, nillable = true)
    protected String libListeElp;
    @XmlElement(nillable = true)
    protected String temSpecialTraitementPRC;
    @XmlElement(required = true, nillable = true)
    protected TableauElementPedagogiDTO3 listElementPedagogi;

    /**
     * Obtient la valeur de la propriété codListeElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodListeElp() {
        return codListeElp;
    }

    /**
     * Définit la valeur de la propriété codListeElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodListeElp(String value) {
        this.codListeElp = value;
    }

    /**
     * Obtient la valeur de la propriété typListeElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTypListeElp() {
        return typListeElp;
    }

    /**
     * Définit la valeur de la propriété typListeElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTypListeElp(String value) {
        this.typListeElp = value;
    }

    /**
     * Obtient la valeur de la propriété libCourtListeElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibCourtListeElp() {
        return libCourtListeElp;
    }

    /**
     * Définit la valeur de la propriété libCourtListeElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibCourtListeElp(String value) {
        this.libCourtListeElp = value;
    }

    /**
     * Obtient la valeur de la propriété libListeElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibListeElp() {
        return libListeElp;
    }

    /**
     * Définit la valeur de la propriété libListeElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibListeElp(String value) {
        this.libListeElp = value;
    }

    /**
     * Obtient la valeur de la propriété temSpecialTraitementPRC.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemSpecialTraitementPRC() {
        return temSpecialTraitementPRC;
    }

    /**
     * Définit la valeur de la propriété temSpecialTraitementPRC.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemSpecialTraitementPRC(String value) {
        this.temSpecialTraitementPRC = value;
    }

    /**
     * Obtient la valeur de la propriété listElementPedagogi.
     * 
     * @return
     *     possible object is
     *     {@link TableauElementPedagogiDTO3 }
     *     
     */
    public TableauElementPedagogiDTO3 getListElementPedagogi() {
        return listElementPedagogi;
    }

    /**
     * Définit la valeur de la propriété listElementPedagogi.
     * 
     * @param value
     *     allowed object is
     *     {@link TableauElementPedagogiDTO3 }
     *     
     */
    public void setListElementPedagogi(TableauElementPedagogiDTO3 value) {
        this.listElementPedagogi = value;
    }

}

==> apo-ws-client-6.00.51.1-sources.jar: fr/univlorraine/apowsclient/creationSE/ListeElementPedagogiDTO3.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ListeElementPedagogiDTO3 complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ListeElementPedagogiDTO3"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codListeElp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="typListeElp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="libCourtListeElp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="libListeElp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="temSpecialTraitementPRC" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="listElementPedagogi" type="{ListeElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}TableauElementPedagogiDTO3"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ListeElementPedagogiDTO3", namespace = "ListeElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codListeElp",
    "typListeElp",
    "libCourtListeElp",
    "libListeElp",
    "temSpecialTraitementPRC",
    "listElementPedagogi"
})
public class ListeElementPedagogiDTO3 {

    @XmlElement(required = true, nillable = true)
    protected String codListeElp;
    @XmlElement(required = true, nillable = true)
    protected String typListeElp;
    @XmlElement(required = true, nillable = true)
    protected String libCourtListeElp;
    @XmlElement(required = true, nillable = true)
    protected String libListeElp;
    @XmlElement(required = true, nillable = true)
    protected String temSpecialTraitementPRC;
    @XmlElement(required = true, nillable = true)
    protected TableauElementPedagogiDTO3 listElementPedagogi;

    /**
     * Obtient la valeur de la propriété codListeElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodListeElp() {
        return codListeElp;
    }

    /**
     * Définit la valeur de la propriété codListeElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodListeElp(String value) {
        this.codListeElp = value;
    }

    /**
     * Obtient la valeur de la propriété typListeElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTypListeElp() {
        return typListeElp;
    }

    /**
     * Définit la valeur de la propriété typListeElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTypListeElp(String value) {
        this.typListeElp = value;
    }

    /**
     * Obtient la valeur de la propriété libCourtListeElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibCourtListeElp() {
        return libCourtListeElp;
    }

    /**
     * Définit la valeur de la propriété libCourtListeElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibCourtListeElp(String value) {
        this.libCourtListeElp = value;
    }

    /**
     * Obtient la valeur de la propriété libListeElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibListeElp() {
        return libListeElp;
    }

    /**
     * Définit la valeur de la propriété libListeElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibListeElp(String value) {
        this.libListeElp = value;
    }

    /**
     * Obtient la valeur de la propriété temSpecialTraitementPRC.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemSpecialTraitementPRC() {
        return temSpecialTraitementPRC;
    }

    /**
     * Définit la valeur de la propriété temSpecialTraitementPRC.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemSpecialTraitementPRC(String value) {
        this.temSpecialTraitementPRC = value;
    }

    /**
     * Obtient la valeur de la propriété listElementPedagogi.
     * 
     * @return
     *     possible object is
     *     {@link TableauElementPedagogiDTO3 }
     *     
     */
    public TableauElementPedagogiDTO3 getListElementPedagogi() {
        return listElementPedagogi;
    }

    /**
     * Définit la valeur de la propriété listElementPedagogi.
     * 
     * @param value
     *     allowed object is
     *     {@link TableauElementPedagogiDTO3 }
     *     
     */
    public void setListElementPedagogi(TableauElementPedagogiDTO3 value) {
        this.listElementPedagogi = value;
    }

}
